@@ -22,7 +22,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: Toolbar.cc 3727 2004-11-25 11:05:58Z mathias $
+// $Id: Toolbar.cc 3807 2005-01-03 05:00:39Z mathias $
 
 #include "Toolbar.hh"
 
@@ -314,22 +314,22 @@ void Toolbar::updateStrut() {
     case TOPLEFT:
     case TOPCENTER:
     case TOPRIGHT:
-        top = height();
+        top = height() + 2 * theme().border().width();
         break;
     case BOTTOMLEFT:
     case BOTTOMCENTER:
     case BOTTOMRIGHT:
-        bottom = height();
+        bottom = height() + 2 * theme().border().width();
         break;
     case RIGHTTOP:
     case RIGHTCENTER:
     case RIGHTBOTTOM:
-        right = width();
+        right = width() + 2 * theme().border().width();
         break;
     case LEFTTOP:
     case LEFTCENTER:
     case LEFTBOTTOM:
-        left = width();
+        left = width() + 2 * theme().border().width();
         break;
     };
     m_strut = screen().requestStrut(getOnHead(), left, right, top, bottom);
@@ -882,7 +882,7 @@ void Toolbar::setupMenus() {
         place_menu.pop_front();
     }
     menu().insert(_FBTEXT(Menu, Placement, "Placement", "Title of Placement menu"), &placementMenu());
-    placementMenu().update();
+    placementMenu().updateMenu();
 
 
     // this saves resources and clears the slit window to update alpha value
@@ -899,7 +899,7 @@ void Toolbar::setupMenus() {
     alpha_menuitem->setCommand(set_alpha_cmd);
 
     menu().insert(alpha_menuitem);
-    menu().update();
+    menu().updateMenu();
 }
 
 void Toolbar::saveOnHead(int head) {
