@@ -20,7 +20,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: main.cc 3718 2004-11-24 11:46:07Z mathias $
+// $Id: main.cc 3793 2004-12-21 23:42:09Z mathias $
 
 #include "fluxbox.hh"
 #include "version.h"
@@ -106,6 +106,11 @@ void showInfo(ostream &ostr) {
 #endif // HAVE_XPM
         "XPM"<<endl<<
 
+#ifndef HAVE_IMLIB2
+        NOT<<
+#endif // HAVE_IMLIB2
+        "IMLIB2"<<endl<<
+
 #ifndef USE_GNOME
         NOT<<
 #endif // USE_GNOME
